@@ -1,3 +1,4 @@
+import json
 import cloudscraper
 import eospy.cleos
 import eospy.keys
@@ -13,6 +14,8 @@ from .exceptions import (
     CPUlimit, CookiesExpired, 
     ExpiredTransaction, UnknownError
 )
+
+
 class Client:
     """
     ### Methods:
@@ -44,6 +47,10 @@ class Client:
 
         self.name = self.GetName()
 
+
+    def __str__(self):
+        return f"Client(name={self.name}, type={self.type}, node={self.node})"
+
     def __GetNameAnchor(self, permission="active") -> str:
         """
         Get wallet name by public key
@@ -141,9 +148,20 @@ class TX:
         self.actions = list(actions)
         self.actions.reverse()
 
-    def pay_with(self, payer: str, network='mainnet') -> PayWith:
+    def __str__(self):
+        actions = ",\n\n        ".join([f"Action(account={x['account']}, name={x['name']}, authorization={x['authorization']}, data={x['data']})" for x in self.actions])
+        return f"""litewax.Transaction(
+    node={self.client.node},
+    sender={self.client.name},
+    actions=[
+        {actions}
+    ]
+)"""
+
+
+    def pay_with(self, payer: str, custom_payer_client: Client=None, network='mainnet') -> PayWith:
         """Create a paywith object"""
-        return PayWith(self, payer, network)
+        return PayWith(self, payer, custom_payer_client, network)
 
     def get_trx_extend_info(self):
         """
